==> deepin-fcitx5configtool-plugin_6.0.11.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_km_KH.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>កម្មវិធីបន្ថែម</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>ការកំណត់ត្រាមូលដ្ឋាន</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="40"/>
        <source>"Advanced Settings" is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>"ការកំណត់ត្រាមូលដ្ឋាន" មានប្រសិទ្ធភាពតែនៅពេលដែលកម្មវិធីបញ្ចូលមានការកំណត់ត្រាមូលដ្ឋានផ្ទាល់ ហើយការកំណត់ត្រាមូលដ្ឋានដែលកម្មវិធីបញ្ចូលមានផ្ទាល់ នឹងត្រូវបានគោះគង់</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="53"/>
        <source>Global Config</source>
        <translation>ការកំណត់ត្រាភាគទូទៅ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="69"/>
        <source>Add-ons</source>
        <translation>កម្មវិធីបន្ថែម</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="150"/>
        <source>Please enter a new shortcut</source>
        <translation>សូមបញ្ចូលបន្ទាត់ថ្មីនៃការបញ្ជូល</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ផ្ទះឡើង</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>ផ្ទះចុះ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>ការកំណត់ត្រា</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>បំបាក់</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>ស្វែងរក</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ស្វែងរកបន្ថែមនៅ App Store</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>បិទ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>បញ្ចូល</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ការបញ្ជូលច្បាប់</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="49"/>
        <source>Restore Defaults</source>
        <translation>ស្វែងរកការបញ្ជូលច្បាប់ដើម</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="101"/>
        <source>Scroll between input methods</source>
        <translation>ផ្លាស់ប្ដូរកម្មវិធីបញ្ចូលតាមរយៈការផ្ទះផ្ទាល់</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Turn on or off input methods</source>
        <translation>បើកឬបិទកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="135"/>
        <source>Please enter a new shortcut</source>
        <translation>សូមបញ្ចូលបន្ទាត់ថ្មីនៃការបញ្ជូល</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="162"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>វាបើកឬបិទកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។ ប្រសិនបើគ្មេាំងកំណត់ត្រានៃកម្មវិធីបញ្ចូល ឬកម្មវិធីបញ្ចូលដំបូងមិនមានបច្បាប់ វានឹងផ្លាស់ប្ដូរពីកម្មវិធីបញ្ចូលដំបូងទៅកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>កម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល ការបញ្ជូលច្បាប់ និងការកំណត់ត្រាមូលដ្ឋាន</translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_km_KH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="km_KH">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>កម្មវិធីបន្ថែម</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>ការកំណត់ត្រាមូលដ្ឋាន</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;ការកំណត់ត្រាមូលដ្ឋាន&quot; មានប្រសិទ្ធភាពតែនៅពេលដែលកម្មវិធីបញ្ចូលមានការកំណត់ត្រាមូលដ្ឋានផ្ទាល់ ហើយការកំណត់ត្រាមូលដ្ឋានដែលកម្មវិធីបញ្ចូលមានផ្ទាល់ នឹងត្រូវបានគោះគង់</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>ការកំណត់ត្រាភាគទូទៅ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>កម្មវិធីបន្ថែម</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>សូមបញ្ចូលបន្ទាត់ថ្មីនៃការបញ្ជូល</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>ផ្ទះឡើង</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>ផ្ទះចុះ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>ការកំណត់ត្រា</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>បំបាក់</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>ស្វែងរក</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>ស្វែងរកបន្ថែមនៅ App Store</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>បិទ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>បញ្ចូល</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>បញ្ចូលកម្មវិធីបញ្ចូល</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>ការបញ្ជូលច្បាប់</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>ស្វែងរកការបញ្ជូលច្បាប់ដើម</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>ផ្លាស់ប្ដូរកម្មវិធីបញ្ចូលតាមរយៈការផ្ទះផ្ទាល់</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>បើកឬបិទកម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>សូមបញ្ចូលបន្ទាត់ថ្មីនៃការបញ្ជូល</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>វាបើកឬបិទកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។ ប្រសិនបើគ្មេាំងកំណត់ត្រានៃកម្មវិធីបញ្ចូល ឬកម្មវិធីបញ្ចូលដំបូងមិនមានបច្បាប់ វានឹងផ្លាស់ប្ដូរពីកម្មវិធីបញ្ចូលដំបូងទៅកម្មវិធីបញ្ចូលដែលប្រើប្រាស់បច្បាប់។</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>កម្មវិធីបញ្ចូល</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ការគ្រប់គ្រងកម្មវិធីបញ្ចូល ការបញ្ជូលច្បាប់ និងការកំណត់ត្រាមូលដ្ឋាន</translation>
    </message>
</context>
</TS>
